{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#hotspotfilter.cwl",
            "baseCommand": [
                "/bin/bash",
                "/opt/HotspotFilter/src/hotspot_filter.sh"
            ],
            "inputs": [
                {
                    "id": "#hotspotfilter.cwl/hotspotfilter/VCF_A",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-A"
                    }
                },
                {
                    "id": "#hotspotfilter.cwl/hotspotfilter/VCF_B",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-B"
                    }
                },
                {
                    "id": "#hotspotfilter.cwl/hotspotfilter/BED",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-D"
                    }
                }
            ],
            "label": "HotspotFilter",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "-o",
                    "valueFrom": "output/HotspotFiltered.vcf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/hotspot_filter:20200429"
                }
            ],
            "outputs": [
                {
                    "id": "#hotspotfilter.cwl/hotspotfilter/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "output/HotspotFiltered.vcf"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#mnp_filter.cwl",
            "baseCommand": [
                "/usr/local/bin/python",
                "/opt/mnp_filter/src/mnp_filter.py"
            ],
            "inputs": [
                {
                    "id": "#mnp_filter.cwl/mnp_filter/input",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--input"
                    },
                    "label": "VCF file"
                },
                {
                    "id": "#mnp_filter.cwl/mnp_filter/tumor_bam",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bam"
                    },
                    "label": "tumor bam",
                    "secondaryFiles": [
                        ".bai"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#mnp_filter.cwl/mnp_filter/filtered_VCF",
                    "type": "File",
                    "outputBinding": {
                        "glob": "MNP_combined.vcf"
                    }
                }
            ],
            "label": "MNP_filter",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "--output",
                    "valueFrom": "MNP_combined.vcf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dinglab2/mnp_filter:20191211"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "MuTect",
            "baseCommand": [
                "/usr/bin/python",
                "/opt/mutect-tool/src/mutect-tool.py",
                "--workdir",
                "."
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dinglab2/mutect-tool:20200427"
                },
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envName": "JAVA_OPTS",
                            "envValue": "-Xmx2g"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--cosmic"
                    },
                    "secondaryFiles": ".tbi",
                    "id": "#mutect.cwl/cosmic"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "mutect_coverage.wig.txt",
                    "inputBinding": {
                        "prefix": "--coverage_file"
                    },
                    "id": "#mutect.cwl/coverage_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp"
                    },
                    "secondaryFiles": ".tbi",
                    "id": "#mutect.cwl/dbsnp"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 4.0,
                    "inputBinding": {
                        "prefix": "--initial_tumor_lod"
                    },
                    "id": "#mutect.cwl/initial_tumor_lod"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--keep_filtered"
                    },
                    "label": "Retain REJECT variants",
                    "id": "#mutect.cwl/keep_filtered"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "inputBinding": {
                        "prefix": "--ncpus"
                    },
                    "id": "#mutect.cwl/ncpus"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input_file:normal"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mutect.cwl/normal"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "mutect_call_stats.txt",
                    "inputBinding": {
                        "prefix": "--out"
                    },
                    "id": "#mutect.cwl/out"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reference_sequence"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#mutect.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input_file:tumor"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mutect.cwl/tumor"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 6.3,
                    "inputBinding": {
                        "prefix": "--tumor_lod"
                    },
                    "id": "#mutect.cwl/tumor_lod"
                },
                {
                    "type": "string",
                    "default": "mutect.vcf",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#mutect.cwl/vcf"
                }
            ],
            "arguments": [
                {
                    "position": 0,
                    "valueFrom": "--artifact_detection_mode"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.out)"
                    },
                    "id": "#mutect.cwl/call_stats"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.coverage_file)"
                    },
                    "id": "#mutect.cwl/coverage"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf)"
                    },
                    "id": "#mutect.cwl/mutations"
                }
            ],
            "id": "#mutect.cwl"
        },
        {
            "class": "CommandLineTool",
            "id": "#dbsnp_filter.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#dbsnp_filter.cwl/dbsnp_filter/input_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--input_vcf"
                    },
                    "label": "VCF file to process."
                },
                {
                    "id": "#dbsnp_filter.cwl/dbsnp_filter/reference_fasta",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--reference_fasta"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "id": "#dbsnp_filter.cwl/dbsnp_filter/bypass_dbsnp",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bypass_dbsnp"
                    },
                    "label": "Bypass dbSNP filter"
                },
                {
                    "id": "#dbsnp_filter.cwl/dbsnp_filter/debug",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--debug"
                    },
                    "label": "print out processing details to STDERR"
                },
                {
                    "id": "#dbsnp_filter.cwl/dbsnp_filter/dbsnp_db",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--dbsnp_db"
                    },
                    "label": "database for dbSNP filtering",
                    "doc": "Step will be skipped if not defined",
                    "secondaryFiles": [
                        ".tbi"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#dbsnp_filter.cwl/dbsnp_filter/filtered_vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/dbsnp_filter/dbsnp_pass.vcf"
                    }
                }
            ],
            "label": "dbsnp_filter",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "dbsnp_filter"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#merge_vcf.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#merge_vcf.cwl/merge_vcf/strelka_snv_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--strelka_snv_vcf"
                    }
                },
                {
                    "id": "#merge_vcf.cwl/merge_vcf/varscan_indel_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--varscan_indel_vcf"
                    }
                },
                {
                    "id": "#merge_vcf.cwl/merge_vcf/varscan_snv_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--varscan_snv_vcf"
                    }
                },
                {
                    "id": "#merge_vcf.cwl/merge_vcf/pindel_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--pindel_vcf"
                    }
                },
                {
                    "id": "#merge_vcf.cwl/merge_vcf/reference_fasta",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--reference_fasta"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "id": "#merge_vcf.cwl/merge_vcf/bypass_merge",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bypass_merge"
                    },
                    "label": "Bypass merge filter"
                },
                {
                    "id": "#merge_vcf.cwl/merge_vcf/debug",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--debug"
                    },
                    "label": "print out processing details to STDERR"
                },
                {
                    "id": "#merge_vcf.cwl/merge_vcf/strelka_indel_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--strelka_indel_vcf"
                    }
                },
                {
                    "id": "#merge_vcf.cwl/merge_vcf/mutect_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--mutect_vcf"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#merge_vcf.cwl/merge_vcf/merged_vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/merged/merged.filtered.vcf"
                    }
                }
            ],
            "label": "merge_vcf",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "merge_vcf"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#parse_pindel.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#parse_pindel.cwl/parse_pindel/pindel_raw",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--pindel_raw"
                    }
                },
                {
                    "id": "#parse_pindel.cwl/parse_pindel/reference_fasta",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--reference_fasta"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "id": "#parse_pindel.cwl/parse_pindel/pindel_config",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--pindel_config"
                    }
                },
                {
                    "id": "#parse_pindel.cwl/parse_pindel/no_delete_temp",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--no_delete_temp"
                    },
                    "doc": "If set, do not delete large temporary files"
                },
                {
                    "id": "#parse_pindel.cwl/parse_pindel/bypass_cvs",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bypass_cvs"
                    },
                    "label": "skip filtering for CvgVafStrand"
                },
                {
                    "id": "#parse_pindel.cwl/parse_pindel/bypass_homopolymer",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bypass_homopolymer"
                    },
                    "label": "skip filtering for Homopolymer"
                },
                {
                    "id": "#parse_pindel.cwl/parse_pindel/debug",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--debug"
                    },
                    "label": "print out processing details to STDERR"
                }
            ],
            "outputs": [
                {
                    "id": "#parse_pindel.cwl/parse_pindel/pindel_vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/pindel/filter_out/pindel-raw.dat.CvgVafStrand_pass.Homopolymer_pass.vcf"
                    }
                }
            ],
            "label": "parse_pindel",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "parse_pindel"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#parse_varscan_indel.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#parse_varscan_indel.cwl/parse_varscan_indel/varscan_indel_raw",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--varscan_indel_raw"
                    }
                },
                {
                    "id": "#parse_varscan_indel.cwl/parse_varscan_indel/varscan_config",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--varscan_config"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#parse_varscan_indel.cwl/parse_varscan_indel/varscan_indel",
                    "doc": "Final SNV output of parsing",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/varscan/filter_indel_out/varscan.out.som_indel.Somatic.hc.vcf"
                    }
                }
            ],
            "label": "parse_varscan_indel",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "parse_varscan_indel"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#parse_varscan_snv.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#parse_varscan_snv.cwl/parse_varscan_snv/varscan_indel_raw",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--varscan_indel_raw"
                    }
                },
                {
                    "id": "#parse_varscan_snv.cwl/parse_varscan_snv/varscan_snv_raw",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--varscan_snv_raw"
                    }
                },
                {
                    "id": "#parse_varscan_snv.cwl/parse_varscan_snv/varscan_config",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--varscan_config"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#parse_varscan_snv.cwl/parse_varscan_snv/varscan_snv",
                    "doc": "Final SNV output of parsing",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/varscan/filter_snv_out/varscan.out.som_snv.Somatic.hc.somfilter_pass.vcf"
                    }
                }
            ],
            "label": "parse_varscan_snv",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "parse_varscan_snv"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run_pindel.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#run_pindel.cwl/run_pindel/tumor_bam",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--tumor_bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#run_pindel.cwl/run_pindel/normal_bam",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--normal_bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#run_pindel.cwl/run_pindel/reference_fasta",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--reference_fasta"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "id": "#run_pindel.cwl/run_pindel/centromere_bed",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--centromere_bed"
                    }
                },
                {
                    "id": "#run_pindel.cwl/run_pindel/no_delete_temp",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--no_delete_temp"
                    },
                    "label": "Don't delete temp files",
                    "doc": "If set, will not delete large temporary Pindel output"
                },
                {
                    "id": "#run_pindel.cwl/run_pindel/pindel_config",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--pindel_config"
                    },
                    "label": "pindel.ini"
                },
                {
                    "id": "#run_pindel.cwl/run_pindel/chrlist",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--chrlist"
                    },
                    "label": "chrom list",
                    "doc": "List of chromosomes for parallel processing"
                },
                {
                    "id": "#run_pindel.cwl/run_pindel/num_parallel_pindel",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--num_parallel_pindel"
                    },
                    "label": "Number chromosomes run in parallel"
                }
            ],
            "outputs": [
                {
                    "id": "#run_pindel.cwl/run_pindel/pindel_raw",
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n        return 'results/pindel/pindel_out/pindel-raw.dat'\n\n}"
                    }
                }
            ],
            "label": "run_pindel",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "run_pindel"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 28000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run_strelka2.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#run_strelka2.cwl/run_strelka2/tumor_bam",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--tumor_bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#run_strelka2.cwl/run_strelka2/normal_bam",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--normal_bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#run_strelka2.cwl/run_strelka2/reference_fasta",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--reference_fasta"
                    },
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ]
                },
                {
                    "id": "#run_strelka2.cwl/run_strelka2/strelka_config",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--strelka_config"
                    }
                },
                {
                    "id": "#run_strelka2.cwl/run_strelka2/manta_vcf",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--manta_vcf"
                    },
                    "label": "Output from Manta",
                    "doc": "Optional file for use with strelka2 processing"
                },
                {
                    "id": "#run_strelka2.cwl/run_strelka2/call_regions",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--call_regions"
                    },
                    "label": "BED file to restrict strelka2 calling regions",
                    "doc": "bgzip-compressed tabix-indexed BED file",
                    "secondaryFiles": [
                        ".tbi"
                    ]
                },
                {
                    "id": "#run_strelka2.cwl/run_strelka2/num_parallel_strelka2",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--num_parallel_strelka2"
                    },
                    "label": "Number of jobs to run in parallel"
                }
            ],
            "outputs": [
                {
                    "id": "#run_strelka2.cwl/run_strelka2/strelka2_snv_vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    return  'results/strelka2/strelka_out/results/variants/somatic.snvs.vcf.gz'\n}"
                    }
                },
                {
                    "id": "#run_strelka2.cwl/run_strelka2/strelka2_indel_vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    return  'results/strelka2/strelka_out/results/variants/somatic.indels.vcf.gz'\n}"
                    }
                }
            ],
            "label": "run_strelka2",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "run_strelka2"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run_varscan.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#run_varscan.cwl/run_varscan/tumor_bam",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--tumor_bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#run_varscan.cwl/run_varscan/normal_bam",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--normal_bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#run_varscan.cwl/run_varscan/reference_fasta",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--reference_fasta"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "id": "#run_varscan.cwl/run_varscan/varscan_config",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--varscan_config"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#run_varscan.cwl/run_varscan/varscan_indel_raw",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/varscan/varscan_out/varscan.out.som_indel.vcf"
                    }
                },
                {
                    "id": "#run_varscan.cwl/run_varscan/varscan_snv_raw",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/varscan/varscan_out/varscan.out.som_snv.vcf"
                    }
                }
            ],
            "label": "run_varscan",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "run_varscan"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#vaf_length_depth_filters.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#vaf_length_depth_filters.cwl/vaf_length_depth_filters/bypass_vaf",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bypass_vaf"
                    },
                    "label": "skip VAF filter"
                },
                {
                    "id": "#vaf_length_depth_filters.cwl/vaf_length_depth_filters/bypass_length",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bypass_length"
                    },
                    "label": "skip length filter"
                },
                {
                    "id": "#vaf_length_depth_filters.cwl/vaf_length_depth_filters/debug",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--debug"
                    },
                    "label": "print out processing details to STDERR"
                },
                {
                    "id": "#vaf_length_depth_filters.cwl/vaf_length_depth_filters/input_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--input_vcf"
                    },
                    "label": "VCF file to process"
                },
                {
                    "id": "#vaf_length_depth_filters.cwl/vaf_length_depth_filters/vcf_filter_config",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--vcf_filter_config"
                    },
                    "label": "Configuration file for VCF filtering",
                    "doc": "Filters for depth, VAF, read count"
                },
                {
                    "id": "#vaf_length_depth_filters.cwl/vaf_length_depth_filters/bypass_depth",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bypass_depth"
                    },
                    "label": "skip depth filter"
                }
            ],
            "outputs": [
                {
                    "id": "#vaf_length_depth_filters.cwl/vaf_length_depth_filters/filtered_vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/vaf_length_depth_filters/filtered.vcf"
                    }
                }
            ],
            "label": "vaf_length_depth_filters",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "vaf_length_depth_filters"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                },
                {
                    "position": 0,
                    "prefix": "--output_vcf",
                    "valueFrom": "filtered.vcf"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#vcf2maf.cwl",
            "baseCommand": [
                "/usr/local/bin/perl",
                "/opt/vcf2maf.pl"
            ],
            "inputs": [
                {
                    "id": "#vcf2maf.cwl/vcf2maf/ref-fasta",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--ref-fasta"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "id": "#vcf2maf.cwl/vcf2maf/assembly",
                    "type": "string",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--ncbi-build"
                    }
                },
                {
                    "id": "#vcf2maf.cwl/vcf2maf/input-vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--input-vcf"
                    }
                },
                {
                    "id": "#vcf2maf.cwl/vcf2maf/tumor_barcode",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--tumor-id"
                    },
                    "label": "MAF tumor barcode",
                    "doc": "Provides value for Tumor_Sample_Barcode in MAF fiile"
                },
                {
                    "id": "#vcf2maf.cwl/vcf2maf/normal_barcode",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--normal-id"
                    },
                    "label": "MAF normal barcode",
                    "doc": "Provides value for Matched_Norm_Sample_Barcode in MAF file"
                }
            ],
            "outputs": [
                {
                    "id": "#vcf2maf.cwl/vcf2maf/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "result.maf"
                    }
                }
            ],
            "label": "vcf2maf",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "--output-maf",
                    "valueFrom": "result.maf"
                },
                {
                    "position": 0,
                    "prefix": "--vcf-tumor-id",
                    "valueFrom": "TUMOR"
                },
                {
                    "position": 0,
                    "prefix": "--vcf-normal-id",
                    "valueFrom": "NORMAL"
                },
                {
                    "position": 0,
                    "prefix": "",
                    "valueFrom": "--inhibit-vep"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-vcf2maf:20200420"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#vep_annotate.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#vep_annotate.cwl/vep_annotate/input_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--input_vcf"
                    }
                },
                {
                    "id": "#vep_annotate.cwl/vep_annotate/reference_fasta",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--reference_fasta"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "id": "#vep_annotate.cwl/vep_annotate/assembly",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--assembly"
                    },
                    "label": "assembly name for VEP annotation",
                    "doc": "Either GRCh37 or GRCh38 currently accepted"
                },
                {
                    "id": "#vep_annotate.cwl/vep_annotate/vep_cache_version",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--vep_cache_version"
                    },
                    "label": "VEP Cache Version (e.g., 93)"
                },
                {
                    "id": "#vep_annotate.cwl/vep_annotate/vep_cache_gz",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--vep_cache_gz"
                    },
                    "label": "VEP Cache .tar.gz file",
                    "doc": "if defined, extract contents into \"./vep-cache\" and use VEP cache.  Otherwise, perform (much slower) online VEP DB lookups"
                }
            ],
            "outputs": [
                {
                    "id": "#vep_annotate.cwl/vep_annotate/output_dat",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/vep/output_vep.vcf"
                    }
                }
            ],
            "label": "vep_annotate",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "vep_annotate"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                },
                {
                    "position": 0,
                    "prefix": "--vep_opts",
                    "valueFrom": "--hgvs --shift_hgvs 1 --no_escape --symbol --numbers --ccds --uniprot --xref_refseq --sift b --tsl --canonical --total_length --allele_number --variant_class --biotype --appris --flag_pick_allele --check_existing --failed 1 --minimal --pick_order biotype,rank,canonical"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-vep:20200420"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#vep_filter.cwl",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/local/somaticwrapper/SomaticWrapper.pl"
            ],
            "inputs": [
                {
                    "id": "#vep_filter.cwl/vep_filter/input_vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--input_vcf"
                    }
                },
                {
                    "id": "#vep_filter.cwl/vep_filter/af_filter_config",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--af_filter_config"
                    },
                    "label": "Configuration file for af (allele frequency) filter"
                },
                {
                    "id": "#vep_filter.cwl/vep_filter/classification_filter_config",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--classification_filter_config"
                    },
                    "label": "Configuration file for classification filter"
                },
                {
                    "id": "#vep_filter.cwl/vep_filter/bypass_af",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bypass_af"
                    },
                    "label": "Bypass AF filter by retaining all reads"
                },
                {
                    "id": "#vep_filter.cwl/vep_filter/bypass_classification",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--bypass_classification"
                    },
                    "label": "Bypass Classification filter by retaining all reads"
                },
                {
                    "id": "#vep_filter.cwl/vep_filter/debug",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--debug"
                    },
                    "label": "print out processing details to STDERR"
                }
            ],
            "outputs": [
                {
                    "id": "#vep_filter.cwl/vep_filter/output_vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/vep_filter/vep_filtered.vcf"
                    }
                }
            ],
            "label": "vep_filter",
            "arguments": [
                {
                    "position": 99,
                    "prefix": "",
                    "separate": false,
                    "shellQuote": false,
                    "valueFrom": "vep_filter"
                },
                {
                    "position": 0,
                    "prefix": "--results_dir",
                    "valueFrom": "results"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/tindaisy-core:20191108"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#varscan_vcf_remap.cwl",
            "baseCommand": [
                "/usr/local/bin/python",
                "/opt/varscan_vcf_remap/src/varscan_vcf_remap.py"
            ],
            "inputs": [
                {
                    "id": "#varscan_vcf_remap.cwl/varscan_vcf_remap/input",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--input"
                    },
                    "label": "VCF file"
                }
            ],
            "outputs": [
                {
                    "id": "#varscan_vcf_remap.cwl/varscan_vcf_remap/remapped_VCF",
                    "type": "File",
                    "outputBinding": {
                        "glob": "varscan-remapped.vcf"
                    }
                }
            ],
            "label": "varscan_vcf_remap",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "--output",
                    "valueFrom": "varscan-remapped.vcf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mwyczalkowski/varscan_vcf_remap:20191227"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#hotspot_vld.cwl",
            "label": "hotspot_vld",
            "inputs": [
                {
                    "id": "#hotspot_vld.cwl/hotspot_vld/vcf_filter_config_A",
                    "type": "File"
                },
                {
                    "id": "#hotspot_vld.cwl/hotspot_vld/input_vcf",
                    "type": "File"
                },
                {
                    "id": "#hotspot_vld.cwl/hotspot_vld/vcf_filter_config_B",
                    "type": "File"
                },
                {
                    "id": "#hotspot_vld.cwl/hotspot_vld/BED",
                    "type": "File"
                }
            ],
            "outputs": [
                {
                    "id": "#hotspot_vld.cwl/hotspot_vld/output",
                    "outputSource": "#hotspot_vld.cwl/hotspot_vld/hotspotfilter/output",
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "id": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_A",
                    "in": [
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_A/input_vcf",
                            "source": "#hotspot_vld.cwl/hotspot_vld/input_vcf"
                        },
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_A/vcf_filter_config",
                            "source": "#hotspot_vld.cwl/hotspot_vld/vcf_filter_config_A"
                        }
                    ],
                    "out": [
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_A/filtered_vcf"
                        }
                    ],
                    "run": "#vaf_length_depth_filters.cwl",
                    "label": "vaf_length_depth_filters_A"
                },
                {
                    "id": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_B",
                    "in": [
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_B/input_vcf",
                            "source": "#hotspot_vld.cwl/hotspot_vld/input_vcf"
                        },
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_B/vcf_filter_config",
                            "source": "#hotspot_vld.cwl/hotspot_vld/vcf_filter_config_B"
                        }
                    ],
                    "out": [
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_B/filtered_vcf"
                        }
                    ],
                    "run": "#vaf_length_depth_filters.cwl",
                    "label": "vaf_length_depth_filters_B"
                },
                {
                    "id": "#hotspot_vld.cwl/hotspot_vld/hotspotfilter",
                    "in": [
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/hotspotfilter/VCF_A",
                            "source": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_A/filtered_vcf"
                        },
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/hotspotfilter/VCF_B",
                            "source": "#hotspot_vld.cwl/hotspot_vld/vaf_length_depth_filters_B/filtered_vcf"
                        },
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/hotspotfilter/BED",
                            "source": "#hotspot_vld.cwl/hotspot_vld/BED"
                        }
                    ],
                    "out": [
                        {
                            "id": "#hotspot_vld.cwl/hotspot_vld/hotspotfilter/output"
                        }
                    ],
                    "run": "#hotspotfilter.cwl",
                    "label": "HotspotFilter"
                }
            ],
            "requirements": []
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "TinDaisy-Hotspot",
            "inputs": [
                {
                    "id": "#main/no_delete_temp",
                    "type": [
                        "null",
                        "boolean"
                    ]
                },
                {
                    "id": "#main/tumor_bam",
                    "type": "File"
                },
                {
                    "id": "#main/normal_bam",
                    "type": "File"
                },
                {
                    "id": "#main/reference_fasta",
                    "type": "File"
                },
                {
                    "id": "#main/pindel_config",
                    "type": "File"
                },
                {
                    "id": "#main/varscan_config",
                    "type": "File"
                },
                {
                    "id": "#main/pindel_vcf_filter_config",
                    "type": "File"
                },
                {
                    "id": "#main/dbsnp_db",
                    "type": [
                        "null",
                        "File"
                    ]
                },
                {
                    "id": "#main/assembly",
                    "type": [
                        "null",
                        "string"
                    ]
                },
                {
                    "id": "#main/vep_cache_version",
                    "type": [
                        "null",
                        "string"
                    ]
                },
                {
                    "id": "#main/vep_cache_gz",
                    "type": [
                        "null",
                        "File"
                    ]
                },
                {
                    "id": "#main/centromere_bed",
                    "type": [
                        "null",
                        "File"
                    ]
                },
                {
                    "id": "#main/strelka_vcf_filter_config",
                    "type": "File"
                },
                {
                    "id": "#main/varscan_vcf_filter_config",
                    "type": "File"
                },
                {
                    "id": "#main/af_filter_config",
                    "type": "File"
                },
                {
                    "id": "#main/classification_filter_config",
                    "type": "File"
                },
                {
                    "id": "#main/mutect_vcf_filter_config",
                    "type": "File"
                },
                {
                    "id": "#main/strelka_config",
                    "type": "File"
                },
                {
                    "id": "#main/chrlist",
                    "type": [
                        "null",
                        "File"
                    ]
                },
                {
                    "id": "#main/num_parallel_pindel",
                    "type": [
                        "null",
                        "int"
                    ]
                },
                {
                    "id": "#main/num_parallel_strelka2",
                    "type": [
                        "null",
                        "int"
                    ]
                },
                {
                    "id": "#main/tumor_barcode",
                    "type": [
                        "null",
                        "string"
                    ]
                },
                {
                    "id": "#main/normal_barcode",
                    "type": [
                        "null",
                        "string"
                    ]
                },
                {
                    "id": "#main/Hotspot_BED",
                    "type": "File"
                },
                {
                    "id": "#main/canonical_BED",
                    "type": "File"
                },
                {
                    "id": "#main/call_regions",
                    "type": [
                        "null",
                        "File"
                    ]
                },
                {
                    "id": "#main/mutect_vcf_filter_config_A",
                    "type": "File"
                },
                {
                    "id": "#main/pindel_vcf_filter_config_A",
                    "type": "File"
                },
                {
                    "id": "#main/varscan_vcf_filter_config_A",
                    "type": "File"
                },
                {
                    "id": "#main/strelka_vcf_filter_config_A",
                    "type": "File"
                }
            ],
            "outputs": [
                {
                    "id": "#main/output_maf",
                    "outputSource": "#main/vcf2maf/output",
                    "type": [
                        "null",
                        "File"
                    ]
                },
                {
                    "id": "#main/output_vcf",
                    "outputSource": "#main/canonical_filter/output",
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "id": "#main/run_pindel",
                    "in": [
                        {
                            "id": "#main/run_pindel/tumor_bam",
                            "source": "#main/tumor_bam"
                        },
                        {
                            "id": "#main/run_pindel/normal_bam",
                            "source": "#main/normal_bam"
                        },
                        {
                            "id": "#main/run_pindel/reference_fasta",
                            "source": "#main/reference_fasta"
                        },
                        {
                            "id": "#main/run_pindel/centromere_bed",
                            "source": "#main/centromere_bed"
                        },
                        {
                            "id": "#main/run_pindel/no_delete_temp",
                            "source": "#main/no_delete_temp"
                        },
                        {
                            "id": "#main/run_pindel/pindel_config",
                            "source": "#main/pindel_config"
                        },
                        {
                            "id": "#main/run_pindel/chrlist",
                            "source": "#main/chrlist"
                        },
                        {
                            "id": "#main/run_pindel/num_parallel_pindel",
                            "source": "#main/num_parallel_pindel"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/run_pindel/pindel_raw"
                        }
                    ],
                    "run": "#run_pindel.cwl",
                    "label": "run_pindel"
                },
                {
                    "id": "#main/run_varscan",
                    "in": [
                        {
                            "id": "#main/run_varscan/tumor_bam",
                            "source": "#main/tumor_bam"
                        },
                        {
                            "id": "#main/run_varscan/normal_bam",
                            "source": "#main/normal_bam"
                        },
                        {
                            "id": "#main/run_varscan/reference_fasta",
                            "source": "#main/reference_fasta"
                        },
                        {
                            "id": "#main/run_varscan/varscan_config",
                            "source": "#main/varscan_config"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/run_varscan/varscan_indel_raw"
                        },
                        {
                            "id": "#main/run_varscan/varscan_snv_raw"
                        }
                    ],
                    "run": "#run_varscan.cwl",
                    "label": "run_varscan"
                },
                {
                    "id": "#main/parse_pindel",
                    "in": [
                        {
                            "id": "#main/parse_pindel/pindel_raw",
                            "source": "#main/run_pindel/pindel_raw"
                        },
                        {
                            "id": "#main/parse_pindel/reference_fasta",
                            "source": "#main/reference_fasta"
                        },
                        {
                            "id": "#main/parse_pindel/pindel_config",
                            "source": "#main/pindel_config"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/parse_pindel/pindel_vcf"
                        }
                    ],
                    "run": "#parse_pindel.cwl",
                    "label": "parse_pindel"
                },
                {
                    "id": "#main/parse_varscan_snv",
                    "in": [
                        {
                            "id": "#main/parse_varscan_snv/varscan_indel_raw",
                            "source": "#main/run_varscan/varscan_indel_raw"
                        },
                        {
                            "id": "#main/parse_varscan_snv/varscan_snv_raw",
                            "source": "#main/run_varscan/varscan_snv_raw"
                        },
                        {
                            "id": "#main/parse_varscan_snv/varscan_config",
                            "source": "#main/varscan_config"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/parse_varscan_snv/varscan_snv"
                        }
                    ],
                    "run": "#parse_varscan_snv.cwl",
                    "label": "parse_varscan_snv"
                },
                {
                    "id": "#main/parse_varscan_indel",
                    "in": [
                        {
                            "id": "#main/parse_varscan_indel/varscan_indel_raw",
                            "source": "#main/run_varscan/varscan_indel_raw"
                        },
                        {
                            "id": "#main/parse_varscan_indel/varscan_config",
                            "source": "#main/varscan_config"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/parse_varscan_indel/varscan_indel"
                        }
                    ],
                    "run": "#parse_varscan_indel.cwl",
                    "label": "parse_varscan_indel"
                },
                {
                    "id": "#main/merge_vcf",
                    "in": [
                        {
                            "id": "#main/merge_vcf/strelka_snv_vcf",
                            "source": "#main/hotspot_vld_strelka_snv/output"
                        },
                        {
                            "id": "#main/merge_vcf/varscan_indel_vcf",
                            "source": "#main/hotspot_vld_varscan_indel/output"
                        },
                        {
                            "id": "#main/merge_vcf/varscan_snv_vcf",
                            "source": "#main/hotspot_vld_varscan_snv/output"
                        },
                        {
                            "id": "#main/merge_vcf/pindel_vcf",
                            "source": "#main/hotspot_vld_pindel/output"
                        },
                        {
                            "id": "#main/merge_vcf/reference_fasta",
                            "source": "#main/reference_fasta"
                        },
                        {
                            "id": "#main/merge_vcf/strelka_indel_vcf",
                            "source": "#main/hotspot_vld_strelka_indel/output"
                        },
                        {
                            "id": "#main/merge_vcf/mutect_vcf",
                            "source": "#main/hotspot_vld_mutect/output"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/merge_vcf/merged_vcf"
                        }
                    ],
                    "run": "#merge_vcf.cwl",
                    "label": "merge_vcf"
                },
                {
                    "id": "#main/dbsnp_filter",
                    "in": [
                        {
                            "id": "#main/dbsnp_filter/input_vcf",
                            "source": "#main/mnp_filter/filtered_VCF"
                        },
                        {
                            "id": "#main/dbsnp_filter/reference_fasta",
                            "source": "#main/reference_fasta"
                        },
                        {
                            "id": "#main/dbsnp_filter/dbsnp_db",
                            "source": "#main/dbsnp_db"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/dbsnp_filter/filtered_vcf"
                        }
                    ],
                    "run": "#dbsnp_filter.cwl",
                    "label": "dbsnp_filter"
                },
                {
                    "id": "#main/vep_annotate",
                    "in": [
                        {
                            "id": "#main/vep_annotate/input_vcf",
                            "source": "#main/dbsnp_filter/filtered_vcf"
                        },
                        {
                            "id": "#main/vep_annotate/reference_fasta",
                            "source": "#main/reference_fasta"
                        },
                        {
                            "id": "#main/vep_annotate/assembly",
                            "source": "#main/assembly"
                        },
                        {
                            "id": "#main/vep_annotate/vep_cache_version",
                            "source": "#main/vep_cache_version"
                        },
                        {
                            "id": "#main/vep_annotate/vep_cache_gz",
                            "source": "#main/vep_cache_gz"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/vep_annotate/output_dat"
                        }
                    ],
                    "run": "#vep_annotate.cwl",
                    "label": "vep_annotate"
                },
                {
                    "id": "#main/vep_filter",
                    "in": [
                        {
                            "id": "#main/vep_filter/input_vcf",
                            "source": "#main/vep_annotate/output_dat"
                        },
                        {
                            "id": "#main/vep_filter/af_filter_config",
                            "source": "#main/af_filter_config"
                        },
                        {
                            "id": "#main/vep_filter/classification_filter_config",
                            "source": "#main/classification_filter_config"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/vep_filter/output_vcf"
                        }
                    ],
                    "run": "#vep_filter.cwl",
                    "label": "vep_filter"
                },
                {
                    "id": "#main/mutect",
                    "in": [
                        {
                            "id": "#main/mutect/normal",
                            "source": "#main/normal_bam"
                        },
                        {
                            "id": "#main/mutect/reference",
                            "source": "#main/reference_fasta"
                        },
                        {
                            "id": "#main/mutect/tumor",
                            "source": "#main/tumor_bam"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/mutect/call_stats"
                        },
                        {
                            "id": "#main/mutect/coverage"
                        },
                        {
                            "id": "#main/mutect/mutations"
                        }
                    ],
                    "run": "#mutect.cwl",
                    "label": "MuTect"
                },
                {
                    "id": "#main/run_strelka2",
                    "in": [
                        {
                            "id": "#main/run_strelka2/tumor_bam",
                            "source": "#main/tumor_bam"
                        },
                        {
                            "id": "#main/run_strelka2/normal_bam",
                            "source": "#main/normal_bam"
                        },
                        {
                            "id": "#main/run_strelka2/reference_fasta",
                            "source": "#main/reference_fasta"
                        },
                        {
                            "id": "#main/run_strelka2/strelka_config",
                            "source": "#main/strelka_config"
                        },
                        {
                            "id": "#main/run_strelka2/call_regions",
                            "source": "#main/call_regions"
                        },
                        {
                            "id": "#main/run_strelka2/num_parallel_strelka2",
                            "source": "#main/num_parallel_strelka2"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/run_strelka2/strelka2_snv_vcf"
                        },
                        {
                            "id": "#main/run_strelka2/strelka2_indel_vcf"
                        }
                    ],
                    "run": "#run_strelka2.cwl",
                    "label": "run_strelka2"
                },
                {
                    "id": "#main/mnp_filter",
                    "in": [
                        {
                            "id": "#main/mnp_filter/input",
                            "source": "#main/merge_vcf/merged_vcf"
                        },
                        {
                            "id": "#main/mnp_filter/tumor_bam",
                            "source": "#main/tumor_bam"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/mnp_filter/filtered_VCF"
                        }
                    ],
                    "run": "#mnp_filter.cwl",
                    "label": "MNP_filter"
                },
                {
                    "id": "#main/vcf2maf",
                    "in": [
                        {
                            "id": "#main/vcf2maf/ref-fasta",
                            "source": "#main/reference_fasta"
                        },
                        {
                            "id": "#main/vcf2maf/assembly",
                            "source": "#main/assembly"
                        },
                        {
                            "id": "#main/vcf2maf/input-vcf",
                            "source": "#main/canonical_filter/output"
                        },
                        {
                            "id": "#main/vcf2maf/tumor_barcode",
                            "source": "#main/tumor_barcode"
                        },
                        {
                            "id": "#main/vcf2maf/normal_barcode",
                            "source": "#main/normal_barcode"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/vcf2maf/output"
                        }
                    ],
                    "run": "#vcf2maf.cwl",
                    "label": "vcf2maf"
                },
                {
                    "id": "#main/varscan_indel_vcf_remap",
                    "in": [
                        {
                            "id": "#main/varscan_indel_vcf_remap/input",
                            "source": "#main/parse_varscan_indel/varscan_indel"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/varscan_indel_vcf_remap/remapped_VCF"
                        }
                    ],
                    "run": "#varscan_vcf_remap.cwl",
                    "label": "varscan_indel_vcf_remap"
                },
                {
                    "id": "#main/varscan_snv_vcf_remap",
                    "in": [
                        {
                            "id": "#main/varscan_snv_vcf_remap/input",
                            "source": "#main/parse_varscan_snv/varscan_snv"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/varscan_snv_vcf_remap/remapped_VCF"
                        }
                    ],
                    "run": "#varscan_vcf_remap.cwl",
                    "label": "varscan_snv_vcf_remap"
                },
                {
                    "id": "#main/canonical_filter",
                    "in": [
                        {
                            "id": "#main/canonical_filter/VCF_A",
                            "source": "#main/vep_filter/output_vcf"
                        },
                        {
                            "id": "#main/canonical_filter/BED",
                            "source": "#main/canonical_BED"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/canonical_filter/output"
                        }
                    ],
                    "run": "#hotspotfilter.cwl",
                    "label": "CanonicalFilter"
                },
                {
                    "id": "#main/hotspot_vld_mutect",
                    "in": [
                        {
                            "id": "#main/hotspot_vld_mutect/vcf_filter_config_A",
                            "source": "#main/mutect_vcf_filter_config_A"
                        },
                        {
                            "id": "#main/hotspot_vld_mutect/input_vcf",
                            "source": "#main/mutect/mutations"
                        },
                        {
                            "id": "#main/hotspot_vld_mutect/vcf_filter_config_B",
                            "source": "#main/mutect_vcf_filter_config"
                        },
                        {
                            "id": "#main/hotspot_vld_mutect/BED",
                            "source": "#main/Hotspot_BED"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/hotspot_vld_mutect/output"
                        }
                    ],
                    "run": "#hotspot_vld.cwl",
                    "label": "hotspot_vld_mutect"
                },
                {
                    "id": "#main/hotspot_vld_pindel",
                    "in": [
                        {
                            "id": "#main/hotspot_vld_pindel/vcf_filter_config_A",
                            "source": "#main/pindel_vcf_filter_config_A"
                        },
                        {
                            "id": "#main/hotspot_vld_pindel/input_vcf",
                            "source": "#main/parse_pindel/pindel_vcf"
                        },
                        {
                            "id": "#main/hotspot_vld_pindel/vcf_filter_config_B",
                            "source": "#main/pindel_vcf_filter_config"
                        },
                        {
                            "id": "#main/hotspot_vld_pindel/BED",
                            "source": "#main/Hotspot_BED"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/hotspot_vld_pindel/output"
                        }
                    ],
                    "run": "#hotspot_vld.cwl",
                    "label": "hotspot_vld_pindel"
                },
                {
                    "id": "#main/hotspot_vld_varscan_snv",
                    "in": [
                        {
                            "id": "#main/hotspot_vld_varscan_snv/vcf_filter_config_A",
                            "source": "#main/varscan_vcf_filter_config_A"
                        },
                        {
                            "id": "#main/hotspot_vld_varscan_snv/input_vcf",
                            "source": "#main/varscan_snv_vcf_remap/remapped_VCF"
                        },
                        {
                            "id": "#main/hotspot_vld_varscan_snv/vcf_filter_config_B",
                            "source": "#main/varscan_vcf_filter_config"
                        },
                        {
                            "id": "#main/hotspot_vld_varscan_snv/BED",
                            "source": "#main/Hotspot_BED"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/hotspot_vld_varscan_snv/output"
                        }
                    ],
                    "run": "#hotspot_vld.cwl",
                    "label": "hotspot_vld_varscan_snv"
                },
                {
                    "id": "#main/hotspot_vld_varscan_indel",
                    "in": [
                        {
                            "id": "#main/hotspot_vld_varscan_indel/vcf_filter_config_A",
                            "source": "#main/varscan_vcf_filter_config_A"
                        },
                        {
                            "id": "#main/hotspot_vld_varscan_indel/input_vcf",
                            "source": "#main/varscan_indel_vcf_remap/remapped_VCF"
                        },
                        {
                            "id": "#main/hotspot_vld_varscan_indel/vcf_filter_config_B",
                            "source": "#main/varscan_vcf_filter_config"
                        },
                        {
                            "id": "#main/hotspot_vld_varscan_indel/BED",
                            "source": "#main/Hotspot_BED"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/hotspot_vld_varscan_indel/output"
                        }
                    ],
                    "run": "#hotspot_vld.cwl",
                    "label": "hotspot_vld_varscan_indel"
                },
                {
                    "id": "#main/hotspot_vld_strelka_snv",
                    "in": [
                        {
                            "id": "#main/hotspot_vld_strelka_snv/vcf_filter_config_A",
                            "source": "#main/strelka_vcf_filter_config_A"
                        },
                        {
                            "id": "#main/hotspot_vld_strelka_snv/input_vcf",
                            "source": "#main/run_strelka2/strelka2_snv_vcf"
                        },
                        {
                            "id": "#main/hotspot_vld_strelka_snv/vcf_filter_config_B",
                            "source": "#main/strelka_vcf_filter_config"
                        },
                        {
                            "id": "#main/hotspot_vld_strelka_snv/BED",
                            "source": "#main/Hotspot_BED"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/hotspot_vld_strelka_snv/output"
                        }
                    ],
                    "run": "#hotspot_vld.cwl",
                    "label": "hotspot_vld_strelka_snv"
                },
                {
                    "id": "#main/hotspot_vld_strelka_indel",
                    "in": [
                        {
                            "id": "#main/hotspot_vld_strelka_indel/vcf_filter_config_A",
                            "source": "#main/strelka_vcf_filter_config_A"
                        },
                        {
                            "id": "#main/hotspot_vld_strelka_indel/input_vcf",
                            "source": "#main/run_strelka2/strelka2_indel_vcf"
                        },
                        {
                            "id": "#main/hotspot_vld_strelka_indel/vcf_filter_config_B",
                            "source": "#main/strelka_vcf_filter_config"
                        },
                        {
                            "id": "#main/hotspot_vld_strelka_indel/BED",
                            "source": "#main/Hotspot_BED"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/hotspot_vld_strelka_indel/output"
                        }
                    ],
                    "run": "#hotspot_vld.cwl",
                    "label": "hotspot_vld_strelka_indel"
                }
            ],
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0"
}
